/* -*-c-*- */
#include "libs/fvwmlib.h"

/*
 *
 * Subroutine Prototypes
 *
 */
RETSIGTYPE DeadPipe(int nonsense);




